@@ -5,8 +5,9 @@
 extern "C" {
 #endif
 
-#include <Rdefines.h> /* Rinternals.h + GET_SLOT etc */
+#include <ctype.h>
 #include <R.h>  /* includes Rconfig.h */
+#include <Rdefines.h> /* Rinternals.h + GET_SLOT etc */
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
@@ -15,6 +16,11 @@ extern "C" {
 #define _(String) (String)
 #endif
 
+#ifdef __GNUC__
+# undef alloca
+# define alloca(x) __builtin_alloca((x))
+#endif
+
 #define Alloca(n, t)   (t *) alloca( (size_t) ( (n) * sizeof(t) ) )
 
 SEXP triangularMatrix_validate(SEXP obj);
