@@ -56,7 +56,8 @@ SEXP LU_expand(SEXP x)
     SET_SLOT(U, Matrix_diagSym, mkString("N"));
     make_d_matrix_triangular(REAL(GET_SLOT(U, Matrix_xSym)), U);
     SET_SLOT(P, Matrix_DimSym, duplicate(dd));
-    iperm = Calloc(n, int);
+    iperm = Alloca(n, int);
+    R_CheckStack();
     perm = INTEGER(ALLOC_SLOT(P, Matrix_permSym, INTSXP, n));
 
     for (i = 0; i < n; i++) iperm[i] = i + 1; /* initialize permutation*/
@@ -71,7 +72,6 @@ SEXP LU_expand(SEXP x)
     }
 				/* invert the inverse */
     for (i = 0; i < n; i++) perm[iperm[i] - 1] = i + 1;
-    Free(iperm);
     UNPROTECT(1);
     return val;
 }
